"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = compilerFlags;

function compilerFlags({
  types: t
}, opts) {
  if (!opts.flags) {
    throw new Error(`flags option needs to be set`);
  }

  if (!opts.availableFlags) {
    throw new Error(`availableFlags option needs to be set`);
  }

  return {
    name: `babel-transform-compiler-flags`,
    visitor: {
      Identifier(nodePath, state) {
        const flags = state.opts.flags;
        const availableFlags = state.opts.availableFlags;

        if (nodePath.node.name === `_CFLAGS_` && t.isMemberExpression(nodePath.parent)) {
          const cFlag = nodePath.parent.property.name;

          if (!availableFlags.includes(cFlag)) {
            throw new Error(`${cFlag} is not part of the available compiler flags.`);
          }

          nodePath.parentPath.replaceWith(t.stringLiteral(flags[cFlag] ? flags[cFlag] : ``));
        }
      }

    }
  };
}